@@ -13,8 +13,7 @@ environ.Env.read_env(BASE_DIR + '/.env')
 
 path_webspace = os.path.dirname(webspace.__file__)
 DEBUG = env.bool('DEBUG', default=True)
-IS_WEBSPACE = env.bool('IS_WEBSPACE', default=False)
-SITE_NAME = env.str('APP_NAME')
+SITE_NAME = env.str('APP_NAME', default='webspace')
 DOMAINS_NAME = env.list('DOMAINS_NAME')
 BUCKET_NAME = env.str('BUCKET_NAME')
 BUCKET_URL = env.str('BUCKET_URL')
@@ -28,6 +27,7 @@ DATABASES = {
     )
 }
 VERSION = base_settings.get_package_version(os.path.join(BASE_DIR, 'package.json'))
+IS_WEBSPACE = True if SITE_NAME == 'webspace' else False
 if IS_WEBSPACE:
     VERSION_WEBSPACE = VERSION
 else:
@@ -204,3 +204,5 @@ CSP_CONNECT_SRC = (
     'fonts.gstatic.com',
     "assets.calendly.com",
 )
+
+WY_LOCALE = 'en_US'
